<?php

namespace Drupal\liqpay\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\liqpay\API\LiqPayApi;
use Drupal\Core\Url;

class PaymentForm extends FormBase{
  	
    protected $liqPay;

    function __construct(){
        $this->liqPay = \Drupal::service('LiqPay');
    }
    public function getFormId(){
    	return 'payment_form';
  	}
  	public function buildForm(array $form, FormStateInterface $form_state, $payment = []){
        if(empty($payment)){
            throw new NotFoundHttpException();
        }
        $form['#id'] = 'payment_form';
        $form['#attached']['library'][] = 'liqpay/css';
        $form['info'] = [
            '#type'         => 'inline_template',
            '#template'     => '<div class="sum"><label>{{ label }}:</label> {{ sum }} {{ currency }}</div>',
            '#context'      => [
                'label'         => $this->liqPay->t('Sum'),
            ]
        ];
        $form['actions'] = [
            '#type'         => 'actions',
            'submit'        => [
                '#type'         => 'submit',
                '#value'        => $this->liqPay->t('Pay')
            ]
        ];
        // ---
        $payment->result_url = Url::fromRoute('liqpay.pages', ['page_type' => 'payment_result'],['absolute' => TRUE])->toString();
        $payment->callback_url = Url::fromRoute('liqpay.pages', ['page_type' => 'api'],['absolute' => TRUE])->toString();
        // Payment alter
        $this->basketPaymentFormAlter($form, $form_state, $payment);
        // ---
        $form['info']['#context']['currency'] = $form['#params']['currency'];
        $form['info']['#context']['sum'] = $form['#params']['amount'];
	  	return $form;
  	}
  	public function submitForm(array &$form, FormStateInterface $form_state){
  		
  	}
    public function basketPaymentFormAlter(&$form, &$form_state, $payment){
        
        $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();
        $config = $this->liqPay->getConfig();

        $form['#params'] = [
            'action'         => $this->liqPay::LIQPAY_ACTION,
            'amount'         => $payment->amount,
            'currency'       => $payment->currency,
            'description'    => !empty($config['description'][$langcode]) ? $config['description'][$langcode] : 'Payment',
            'order_id'       => $payment->id.'-'.time().rand(0, 999),
            'version'        => $this->liqPay::LIQPAY_VERSION,
            'server_url'     => $payment->callback_url,
            'result_url'     => $payment->result_url
        ];
        // Alter
        \Drupal::moduleHandler()->alter('liqpay_payment_params', $form['#params'], $payment, $config);
        // ---
        $liqpay = new LiqPayApi(
            $config['public_key'],
            $config['private_key']
        );
        $liqpay->form_alter($form, $form['#params']);
        // ---
        $_SESSION['liqpay_last_pay'] = $payment->id;
    }
}