<?php

namespace Drupal\liqpay\Plugin\Basket\Payment;

use Drupal\basket\Plugins\Payment\BasketPaymentInterface;
use Drupal\basket\Plugins\Payment\Annotation\BasketPayment;
use Drupal\liqpay\Form\PaymentForm;
use Drupal\liqpay\Controller\LiqpayPages;

/**
 * @BasketPayment(
 *          id        = "liqpay",
 *          name      = "LiqPay",
 * )
 */
class BasketLiqpay implements BasketPaymentInterface {

	protected $liqPay;
	protected $basket;

	function __construct(){
		$this->liqPay = \Drupal::service('LiqPay');
		$this->basket = \Drupal::service('Basket');
	}
	/*
	 	Alter for making adjustments when creating a payment item
	*/
	public function settingsFormAlter(&$form, $form_state){
		$tid = $form['tid']['#value'];
		$form['settings'] = [
			'#type'			=> 'details',
			'#title'		=> $this->liqPay->t('Settings'),
			'#open'			=> TRUE,
			'#parents'		=> ['basket_payment_liqpay_settings'],
			'#tree'			=> TRUE,
			'status'		=> [
				'#type'			=> 'select',
				'#title'		=> $this->liqPay->t('Change order status after payment to'),
				'#options'		=> $this->basket->Term()->getOptions('fin_status'),
				'#empty_option'	=> $this->liqPay->t('Do not change status'),
				'#default_value'=> $this->basket->getSettings('payment_settings', $tid.'.status')
			]
		];
		$form['#submit'][] = [$this, 'formSubmit'];
	}
	public function formSubmit($form, $form_state){
		$tid = $form_state->getValue('tid');
		if(!empty($tid)){
			$this->basket->setSettings(
				'payment_settings', 
	            $tid, 
	            $form_state->getValue('basket_payment_liqpay_settings')
			);
		}
	}
	/*
		Interpretation of the list of settings for pages with payment types
		return $items = []
	*/
	public function getSettingsInfoList($tid){
		$items = [];
		if(!empty($settings = $this->basket->getSettings('payment_settings', $tid))){
			$value = $this->liqPay->t('Do not change status');
			if(!empty($settings['status']) && !empty($term = $this->basket->Term()->load($settings['status']))){
				$value = $this->basket->Translate()->t($term->name);
			}
			$items[] = [
				'#type'			=> 'inline_template',
				'#template'		=> '<b>{{ label }}: </b> {{ value }}',
				'#context'		=> [
					'label'			=> $this->liqPay->t('Change order status after payment to'),
					'value'			=> $value
				]
			];
		}
		return $items;
	}
	/*
		Creation of payment
		return [
		 	'payID'			=> 10,
	 		'redirectUrl'	=> \Drupal::url('payment.routing')
	 	];
	*/
	public function createPayment($entity, $order){
		if(!empty($order->pay_price)){
			$currency = $this->basket->Currency()->load($order->pay_currency);
			$payment = $this->liqPay->load([
				'nid'			=> $entity->id(),
				'create_new'	=> TRUE,
				'amount'		=> $order->pay_price,
				'currency'		=> $currency->iso
			]);
			if(!empty($payment)){
				return [
					'payID'			=> $payment->id,
					'redirectUrl'	=> NULL
				];
			}
		}
		return [
			'payID'			=> NULL,
			'redirectUrl'	=> NULL
		];
	}
	/*
		Alter page redirects for payment
	*/
	public function loadPayment($id){
		$payment = $this->liqPay->load(['id' => $id]);
		if(!empty($payment)){
			$successes = explode('|', $this->liqPay::LIQPAY_SUCCESS_STATUS);
			return [
				'payment'		=> $payment,
				'isPay'			=> !empty($payment->status) && in_array($payment->status, $successes) ? TRUE : FALSE
			];
		}
	}
	/*
		Alter page redirects for payment
	*/
	public function paymentFormAlter(&$form, $form_state, $payment){
		$PaymentForm = new PaymentForm();
		$PaymentForm->basketPaymentFormAlter($form, $form_state, $payment);
	}
	/*
		Alter processing pages of interaction between the payment system and the site
		$pageType = callback/result/cancel
	*/
	public function basketPaymentPages($pageType){
		$LiqpayPages = new LiqpayPages();
		switch($pageType){
			case'callback':
				return $LiqpayPages->pages('api');
			break;
			case'cancel':
			case'result':
				return $LiqpayPages->pages('payment_result');
			break;
		}
	}
	/*
		Order update upon successful ordering by payment item settings
	*/
	public function updateOrderBySettings($pid, $Order){
		$order = $Order->load();
		if(!empty($order) && !empty($settings = $this->basket->getSettings('payment_settings', $pid))){
			if(!empty($settings['status'])){
				$order->fin_status = $settings['status'];
				$Order->replaceOrder($order);
				$Order->save();
			}
		}
	}
}